@@ -17,7 +17,7 @@ class DynamoDbHelper:
 
     @staticmethod
     def insert_item(table_name, item_data):
-        ddb = AwsHelper().getResource("dynamodb")
+        ddb = AwsHelper().get_resource("dynamodb")
         table = ddb.Table(table_name)
         ddb_response = table.put_item(Item=item_data)
         return ddb_response
@@ -26,7 +26,7 @@ class DynamoDbHelper:
     def delete_items(table_name, key, value, sk):
         items = DynamoDbHelper.get_items(table_name, key, value)
         if items:
-            ddb = AwsHelper().getResource("dynamodb")
+            ddb = AwsHelper().get_resource("dynamodb")
             table = ddb.Table(table_name)
             for item in items:
                 print("Deleting...")
@@ -35,6 +35,6 @@ class DynamoDbHelper:
                 table.delete_item(
                     Key={
                         key: value,
-                        sk : item[sk]
+                        sk: item[sk]
                     })
                 print("Deleted...")
\ No newline at end of file
